# Copyright (c) 2025 Aaryan Guglani and FEDzk Contributors
# SPDX-License-Identifier: MIT

# Copyright (c) 2025 Aaryan Guglani and FEDzk Contributors
# SPDX-License-Identifier: MIT

"""FEDzk: Secure Federated Learning with Zero-Knowledge Proofs."""

__version__ = "1.0.1"
